==> yak-dev-jackson-2.2.1-sources.jar: org/crazyyak/dev/jackson/YakJacksonObjectMapper.java <==
/*
 * Copyright 2012 Jacob D Parr
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.crazyyak.dev.jackson;

import com.fasterxml.jackson.databind.*;
import com.fasterxml.jackson.datatype.joda.JodaModule;

import java.util.*;

public class YakJacksonObjectMapper extends ObjectMapper {

  private final Collection<? extends Module> modules;
  private final Collection<? extends YakJacksonInjectable> injectables;

  private static Collection<? extends Module> defaultModules() {
    return Arrays.asList(
        new JodaModule(),
        new YakJacksonModule());
  }

  public YakJacksonObjectMapper() {
    this(defaultModules(), Collections.<YakJacksonInjectable>emptyList());
  }

  public YakJacksonObjectMapper(Collection<? extends YakJacksonInjectable> injectables) {
    this(defaultModules(), injectables);
  }

  public YakJacksonObjectMapper(Collection<? extends Module> modules, Collection<? extends YakJacksonInjectable> injectables) {

    this.modules = modules;
    this.injectables = injectables;

    // Stops LocalDateTime from being rendered as array.
    configure(SerializationFeature.WRITE_DATES_AS_TIMESTAMPS, false);

    // Pretty printing
    configure(SerializationFeature.INDENT_OUTPUT, true);

    // Empty strings to null
    configure(DeserializationFeature.ACCEPT_EMPTY_STRING_AS_NULL_OBJECT, false);

    // Allows for extra data.
    configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, true);

    // Register Joda and Dev modules
    for (Module module : modules) {
      registerModule(module);
    }

    YakJacksonInjectableValues injectableValues = new YakJacksonInjectableValues();
    for (YakJacksonInjectable injectable : injectables) {
      injectableValues.addValue(injectable.getKey(), injectable.getValue());
    }
    setInjectableValues(injectableValues);
  }

  @Override
  public ObjectMapper copy() {
    _checkInvalidCopy(YakJacksonObjectMapper.class);
    return new YakJacksonObjectMapper(getModules(), getInjectables());
  }

  public Collection<? extends Module> getModules() {
    return Collections.unmodifiableCollection(modules);
  }

  public Collection<? extends YakJacksonInjectable> getInjectables() {
    return Collections.unmodifiableCollection(injectables);
  }
}

==> yak-dev-jackson-2.4.3-sources.jar: org/crazyyak/dev/jackson/YakJacksonObjectMapper.java <==
/*
 * Copyright 2012 Jacob D Parr
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.crazyyak.dev.jackson;

import com.fasterxml.jackson.databind.*;
import com.fasterxml.jackson.datatype.joda.JodaModule;

import java.util.*;

public class YakJacksonObjectMapper extends ObjectMapper {

  private final Collection<? extends Module> modules;
  private final Collection<? extends YakJacksonInjectable> injectables;

  public static Collection<? extends Module> defaultModules() {
    return Arrays.asList(
        new JodaModule(),
        new YakJacksonModule());
  }

  public YakJacksonObjectMapper() {
    this(defaultModules(), Collections.<YakJacksonInjectable>emptyList());
  }

  public YakJacksonObjectMapper(Collection<? extends YakJacksonInjectable> injectables) {
    this(defaultModules(), injectables);
  }

  public YakJacksonObjectMapper(Collection<? extends Module> modules, Collection<? extends YakJacksonInjectable> injectables) {

    this.modules = modules;
    this.injectables = injectables;

    // Stops LocalDateTime from being rendered as array.
    configure(SerializationFeature.WRITE_DATES_AS_TIMESTAMPS, false);

    // Pretty printing
    configure(SerializationFeature.INDENT_OUTPUT, true);

    // Empty strings to null
    configure(DeserializationFeature.ACCEPT_EMPTY_STRING_AS_NULL_OBJECT, false);

    // Allows for extra data.
    configure(DeserializationFeature.FAIL_ON_UNKNOWN_PROPERTIES, true);

    // Register Joda and Dev modules
    for (Module module : modules) {
      registerModule(module);
    }

    YakJacksonInjectableValues injectableValues = new YakJacksonInjectableValues();
    for (YakJacksonInjectable injectable : injectables) {
      injectableValues.addValue(injectable.getKey(), injectable.getValue());
    }
    setInjectableValues(injectableValues);
  }

  @Override
  public ObjectMapper copy() {
    _checkInvalidCopy(YakJacksonObjectMapper.class);
    return new YakJacksonObjectMapper(getModules(), getInjectables());
  }

  public Collection<? extends Module> getModules() {
    return Collections.unmodifiableCollection(modules);
  }

  public Collection<? extends YakJacksonInjectable> getInjectables() {
    return Collections.unmodifiableCollection(injectables);
  }
}
